==> wikiweb-0.1.4.tar.gz: wikiweb-0.1.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0','requests>=2.19.1','bs4>=0.0.1','networkx>=2.1','numpy>=1.14.0','plotly','lxml']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Tyler Falcoff",
    author_email='tfalcoff@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="Ever wonder if there's a better way to play the link game? Well here you go! Your personal Wikipedia crawler.",
    entry_points={
        'console_scripts': [
            'wikiweb=wikiweb.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='wikiweb',
    name='wikiweb',
    packages=find_packages(include=['wikiweb']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/tyfal/wikiweb',
    version='0.1.4',
    zip_safe=False,
)

==> wikiweb-0.1.5.tar.gz: wikiweb-0.1.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0','requests>=2.19.1','bs4>=0.0.1','networkx>=2.1','numpy>=1.14.0','lxml>=4.2.3','plotly']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Tyler Falcoff",
    author_email='tfalcoff@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="Ever wonder if there's a better way to play the link game? Well here you go! Your personal Wikipedia crawler.",
    entry_points={
        'console_scripts': [
            'wikiweb=wikiweb.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='wikiweb',
    name='wikiweb',
    packages=find_packages(include=['wikiweb']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/tyfal/wikiweb',
    version='0.1.5',
    zip_safe=False,
)
